/**
 *
 * Magnolia Criteria API (http://www.openmindlab.com/lab/products/mgnlcriteria.html)
 * Copyright (C)2009 - 2010, Openmind S.r.l. http://www.openmindonline.it
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sourceforge.openutils.mgnlcriteria.jcr.query.criterion;

import java.io.Serializable;
import java.text.DateFormat;
import java.text.SimpleDateFormat;

import net.sourceforge.openutils.mgnlcriteria.jcr.query.Criteria;
import net.sourceforge.openutils.mgnlcriteria.jcr.query.JCRQueryException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * An object-oriented representation of a query criterion that may be used as a restriction in a <tt>Criteria</tt>
 * query. Built-in criterion types are provided by the <tt>Restrictions</tt> factory class. This interface might be
 * implemented by application classes that define custom restriction criteria.
 * @see Restrictions
 * @see Criteria
 * @author Federico Grilli
 * @version $Id: Criterion.java 2820 2010-07-16 07:33:39Z diego_schivo $
 */
public interface Criterion extends Serializable
{

    Logger log = LoggerFactory.getLogger(Criterion.class);

    String ATTRIBUTE_SELECTOR = "@";

    String JCR_PREFIX = "jcr:";

    String JCR_ROOT = "/jcr:root";

    String ALL_ELEMENTS = "//*";

    String ANY_PROPERTY = ".";

    String XS_DATETIME_FUNCTION = "xs:dateTime";

    String MIDNIGHT = "T00:00:00.000+00:00";

    String T235959 = "T23:59:59.000+00:00";

    String NT_BASE = "nt:base";

    String NOT = " not(";

    String HYPHEN = "-";

    int DAY_MAX = 10;

    int MONTH_MAX = 9;

    DateFormat DATE_FORMAT = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSS");

    /**
     * Render the XPath fragment
     * @param criteria
     * @return String
     * @throws JCRQueryException
     */
    public String toXPathString(Criteria criteria) throws JCRQueryException;

}
